# Bonfo - Betaflight configuration management

[![pypi](https://img.shields.io/pypi/v/bonfo.svg)](https://pypi.org/project/bonfo/)
[![python](https://img.shields.io/pypi/pyversions/bonfo.svg)](https://pypi.org/project/bonfo/)
[![Build Status](https://github.com/destos/bonfo/actions/workflows/dev.yml/badge.svg)](https://github.com/destos/bonfo/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/destos/bonfo/branch/main/graphs/badge.svg)](https://codecov.io/github/destos/bonfo)


* Documentation: <https://destos.github.io/bonfo>
* GitHub: <https://github.com/destos/bonfo>
* PyPI: <https://pypi.org/project/bonfo/>
* Free software: MIT

## Features

* Connects to Betaflight flight controllers
* More soon ( lol )

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.
